@@ -22,6 +22,7 @@
 
 #include <gtk/gtkaccessible.h>
 #include <gail/gailcontainer.h>
+#include <libgail-util/gailtextutil.h>
 
 
 #ifdef __cplusplus
@@ -53,6 +54,10 @@ struct _GailButton
   gchar         *click_keybinding;
   guint         action_idle_handler;
   GQueue        *action_queue;
+
+  GailTextUtil	 *textutil;
+
+  gboolean     default_is_press;
 };
 
 GType gail_button_get_type (void);
